//
//  GlanceController.swift
//  theValueGlance WatchKit Extension
//
//  Created by yoshiyuki oshige on 2015/05/03.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import WatchKit
import Foundation

class GlanceController: WKInterfaceController {

    // ラベルとOutlet接続する
    @IBOutlet weak var myGlanceLabel: WKInterfaceLabel!
    // タイマー
    var timerObj:NSTimer?
    
    // 親アプリから現在値を得る
    func updateValue() {
        let userInfo = ["info": "Glance"]
        // 親アプリにreplyFunc()を送る
        WKInterfaceController.openParentApplication(userInfo, reply: replyFunc)
    }
    
    // 親アプリに送る関数
    func replyFunc(replyInfo: [NSObject: AnyObject]!, error: NSError!) {
        // replyInfoから値を取り出す
        if let nowValue = replyInfo["theValue"] as? Double {
            // グランスに表示する値を更新する
            myGlanceLabel.setText(nowValue.description)
        } else {
            myGlanceLabel.setText("...")
        }
    }
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
    }
    
    override func willActivate() {
        super.willActivate()
        // 最初の表示
        updateValue()
        // updateValue()を定期的に実行するタイマー
        if timerObj == nil {
            timerObj = NSTimer.scheduledTimerWithTimeInterval(3.0, target: self, selector: Selector("updateValue"), userInfo: nil, repeats: true)
        }
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
        // タイマーを止める
        timerObj?.invalidate()
        timerObj = nil
    }

}
