//
//  InterfaceController.swift
//  theValueGlance WatchKit Extension
//
//  Created by yoshiyuki oshige on 2015/05/03.
//  Copyright (c) 2015年 yoshiyuki oshige. All rights reserved.
//

import WatchKit
import Foundation

class InterfaceController: WKInterfaceController {
    
    // ラベルとOutlet接続する
    @IBOutlet weak var nowLabel: WKInterfaceLabel!
    @IBOutlet weak var diffLabel: WKInterfaceLabel!
    // タイマー
    var timerObj:NSTimer?
    var oldValue:Double = 0.0
    
    // 親アプリから現在値を得る
    func updateValue() {
        let userInfo = ["info": "Glance"]
        // 親アプリにreplyFunc()を送る
        WKInterfaceController.openParentApplication(userInfo, reply: replyFunc)
    }
    
    // 親アプリに送る関数
    func replyFunc(replyInfo: [NSObject: AnyObject]!, error: NSError!) {
        // replyInfoから値を取り出す
        if let nowValue = replyInfo["theValue"] as? Double {
            // 画面に表示する値を更新する
            nowLabel.setText(nowValue.description) // 現在値
            // 最後の値との差
            let difference = round((nowValue - oldValue)*10)/10
            diffLabel.setText(difference.description)
            // 値が上昇したら白文字、下降したら赤文字
            if oldValue<=nowValue {
                diffLabel.setTextColor(UIColor.whiteColor())
            } else {
                diffLabel.setTextColor(UIColor.redColor())
            }
            // 現在値を保存する
            oldValue = nowValue
        } else {
            // 値を取得できなかった
            nowLabel.setText("...")
        }

    }
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)    }
    
    override func willActivate() {
        super.willActivate()
        // 最初の表示
        updateValue()
        // updateValue()を定期的に実行するタイマー
        if timerObj == nil {
            timerObj = NSTimer.scheduledTimerWithTimeInterval(1.0, target: self, selector: Selector("updateValue"), userInfo: nil, repeats: true)
        }
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
        // タイマーを止める
        timerObj?.invalidate()
        timerObj = nil
    }

}
